@@ -6,7 +6,8 @@ def rag_query(chat_session, zk, query):
 
     for result in results:
         chat_session.insert_message(LLMMessage(role=MessageRole.Assistant,
-                                               content=f"Excerpt from: {result.excerpt.document_title}\n"
+                                               content=f"Excerpt from: "
+                                                       f"{result.excerpt.document_title}\n"
                                                        + result.excerpt.text))
 
     return chat_session.send(query)
